# pascrd

Progammatic Access (to) Single-Cell Repositories for Download

## About

This package provides various Python apis for programmatically
data from various online single-cell repositories. 

Currently there are apis written for Tabula Sapiens and the
Human Cell Atlas. 

## Installation

```
git clone https://github.com/matt-sd-watson/pascrd.git && cd pascrd
pip install . 
```



